@@ -19,91 +19,70 @@
 #include "amordialog.moc"
 #include "version.h"
 #include <klocale.h>
-#if QT_VERSION >= 199
+#include <qvbox.h>
 #include <kglobal.h>
 #include <kstddirs.h>
-#endif
 
 //---------------------------------------------------------------------------
 //
 // Constructor
 //
 AmorDialog::AmorDialog()
-    : QDialog()
+    : KDialogBase(0, "amordlg", false, QString::null,
+		  KDialogBase::Ok | KDialogBase::Cancel,
+		  KDialogBase::Ok )
 {
     mConfig.read();
+    QVBox *mainwidget = makeVBoxMainWidget();
 
-    QVBoxLayout *layout = new QVBoxLayout(this, 15);
-
-    QHBoxLayout *hb = new QHBoxLayout();
-    layout->addLayout(hb, 1);
+    QHBox *hb = new QHBox(mainwidget);
 
     // Theme list
-    QVBoxLayout *themeBox = new QVBoxLayout();
-    hb->addLayout(themeBox, 1);
+    QVBox *themeBox = new QVBox(hb);
+    themeBox->setSpacing(spacingHint());
 
-    QLabel *label = new QLabel(i18n("Theme:"), this);
+    QLabel *label = new QLabel(i18n("Theme:"), themeBox);
     label->setFixedHeight(label->sizeHint().height());
-    themeBox->addWidget(label);
 
-    mThemeListBox = new QListBox(this);
+    mThemeListBox = new QListBox(themeBox);
     connect(mThemeListBox,SIGNAL(highlighted(int)),SLOT(slotHighlighted(int)));
     mThemeListBox->setMinimumSize(200, 70);
-    themeBox->addWidget(mThemeListBox, 2);
 
-    mAboutEdit = new QMultiLineEdit(this);
+    mAboutEdit = new QMultiLineEdit(themeBox);
     mAboutEdit->setReadOnly(true);
-    mAboutEdit->setMinimumHeight(40);
-    themeBox->addWidget(mAboutEdit, 1);
+    mAboutEdit->setMinimumHeight(60);
+
+    themeBox->setStretchFactor(mThemeListBox, 4);
+    themeBox->setStretchFactor(mAboutEdit, 1);
 
     // Animation offset
-    QVBoxLayout *offsetBox = new QVBoxLayout();
-    hb->addLayout(offsetBox);
+    QVBox *offsetBox = new QVBox(hb);
+    label = new QLabel(i18n("Offset:"), offsetBox);
 
-    label = new QLabel(i18n("Offset:"), this);
     label->setFixedSize(label->sizeHint());
-    offsetBox->addWidget(label);
 
     QSlider *slider = new QSlider(-40, 40, 5, mConfig.mOffset,
-                                    QSlider::Vertical, this);
+                                    QSlider::Vertical, offsetBox);
     connect(slider, SIGNAL(valueChanged(int)), SLOT(slotOffset(int)));
     slider->setFixedWidth(slider->sizeHint().width());
-    offsetBox->addWidget(slider);
 
     // Always on top
-    QCheckBox *checkBox = new QCheckBox(i18n("Always on top"), this);
+    QCheckBox *checkBox = new QCheckBox(i18n("Always on top"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotOnTop(bool)));
     checkBox->setFixedHeight(checkBox->sizeHint().height());
     checkBox->setChecked(mConfig.mOnTop);
-    layout->addWidget(checkBox);
 
-    checkBox = new QCheckBox(i18n("Show random tips"), this);
+    checkBox = new QCheckBox(i18n("Show random tips"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotRandomTips(bool)));
     checkBox->setFixedHeight(checkBox->sizeHint().height());
     checkBox->setChecked(mConfig.mTips);
-    layout->addWidget(checkBox);
 
-    // OK/Cancel
-    hb = new QHBoxLayout();
-    layout->addLayout(hb);
-
-    QPushButton *button = new QPushButton(i18n("&OK"), this);
-    connect(button, SIGNAL(clicked()), SLOT(slotOk()));
-    button->setFixedSize(button->sizeHint());
-    hb->addWidget(button);
-
-    hb->addStretch(1);
-
-    button = new QPushButton(i18n("&Cancel"), this);
-    connect(button, SIGNAL(clicked()), SLOT(slotCancel()));
-    button->setFixedSize(button->sizeHint());
-    hb->addWidget(button);
-
-    layout->activate();
+    connect(this, SIGNAL(okClicked()), SLOT(slotOk()));
+    connect(this, SIGNAL(cancelClicked()), SLOT(slotCancel()));
 
     readThemes();
 
-    resize( 400, 300 );
+    adjustSize();
 }
 
 //---------------------------------------------------------------------------
@@ -120,65 +99,20 @@ AmorDialog::~AmorDialog()
 //
 void AmorDialog::readThemes()
 {
-#if QT_VERSION >= 199
-    QStringList dirs(KGlobal::dirs()->resourceDirs("appdata"));
-    for (QStringList::ConstIterator it1 = dirs.end();
-         it1 != dirs.begin();)
-    {
-       it1--;
-       QDir dir(*it1, "*rc");
-       if (dir.isReadable())
-       {
-          QStringList list = dir.entryList();
-          for (QStringList::ConstIterator it2 = list.begin(); it2 != list.end();
-it2++)  
-          {
-               addTheme(*it1, *it2);
-          }
-       }
-    }	
-#else
-    // read global themes
-    QString path = KApplication::localkdedir().copy();
-    path += "/share/apps/amor";
-
-    QDir dir(path, "*rc");
-    if (dir.isReadable())
-    {
-        const QStrList *list = dir.entryList();
-
-        QStrListIterator it( *list );
-        for (; it.current(); ++it)
-        {
-            addTheme(path, it.current());
-        }
-    }
-
-    // read local themes
-    path = KApplication::kde_datadir().copy();
-    path += "/amor";
-
-    dir.setPath(path);
-    if (dir.isReadable())
-    {
-        const QStrList *list = dir.entryList();
-
-        QStrListIterator it( *list );
-        for (; it.current(); ++it)
-        {
-            addTheme(path, it.current());
-        }
-    }
-#endif
+    QStringList files(KGlobal::dirs()->findAllResources("appdata", "*rc"));
+    for (QStringList::ConstIterator it = files.begin();
+	 it != files.end();
+	 it++)
+      addTheme(*it);
 }
 
 //---------------------------------------------------------------------------
 //
 // Add a single theme to the list
 //
-void AmorDialog::addTheme(QString path, QString file)
+void AmorDialog::addTheme(const QString& file)
 {
-    KSimpleConfig config(path + "/" + file, true);
+    KSimpleConfig config(file, true);
 
     config.setGroup("Config");
 
@@ -188,17 +122,18 @@ void AmorDialog::addTheme(QString path, QString file)
         return;
     }
 
+    pixmapPath += "/";
+
     if (pixmapPath[0] != '/')
     {
-        // relative to config file.
-        pixmapPath = path + "/" + pixmapPath;
+        // relative to config file. We add a / to indicate the dir
+        pixmapPath = locate("appdata", pixmapPath);
     }
 
     QString description = config.readEntry("Description");
     QString about = config.readEntry("About", " ");
     QString pixmapName = config.readEntry("Icon");
 
-    pixmapPath += "/";
     pixmapPath += pixmapName;
 
     QPixmap pixmap(pixmapPath);
