@@ -5,12 +5,12 @@
 // Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
 //
 
-#ifndef AMORTIPS_H 
-#define AMORTIPS_H 
+#ifndef AMORTIPS_H
+#define AMORTIPS_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif 
+#endif
 
 #include <qstrlist.h>
 class QFile;
@@ -24,17 +24,17 @@ class AmorTips
 public:
     AmorTips();
 
-    bool setFile(const char *file);
+    bool setFile(const QString& file);
     void reset();
-    const char *tip();
+    QString tip();
 
 protected:
-    bool read(const char *file);
+    bool read(const QString& file);
     bool readTip(QFile &file);
 
 protected:
-    QStrList mTips;
+    QStringList mTips;
 };
 
-#endif // AMORTIPS_H 
+#endif // AMORTIPS_H
 
