@@ -1,6 +1,6 @@
 /*
  *   kmoon - a moon phase indicator
- *   $Id: kmoon.cpp,v 1.15 2000/02/04 10:19:19 kulow Exp $
+ *   $Id: kmoon.cpp,v 1.16 2000/05/29 08:56:21 coolo Exp $
  *   Copyright (C) 1998  Stephan Kulow
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -204,11 +204,6 @@ int main( int argc, char **argv)
 
     KApplication a;
     MoonWidget *moon = new MoonWidget();
-#warning fix session management
-#if 0
-    kapp->enableSessionManagement( TRUE );
-#endif
-    kapp->setTopWidget(new QWidget);
     a.setMainWidget(moon);
     moon->show();
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
