@@ -1,6 +1,7 @@
 #include <kapp.h>
 
 #include "kinputline.h"
+#include <klocale.h>
 #include "kinputline.moc"
 
 
@@ -9,14 +10,17 @@ KInputLine::KInputLine(QWidget *parent, QString text, QString init)
 {
   int width = 200;
 
+  QFont f = kapp->font();
+  setFont(f);
+
   label = new QLabel(text, this);
   label->adjustSize();
   
   if (label->width() > width)
     width = label->width();
 
-  ok = new QPushButton(kapp->i18n("&OK"), this);
-  cancel = new QPushButton(kapp->i18n("&Cancel"), this);
+  ok = new QPushButton(i18n("&OK"), this);
+  cancel = new QPushButton(i18n("&Cancel"), this);
   ok->adjustSize();
   cancel->adjustSize();
   
@@ -39,9 +43,11 @@ KInputLine::KInputLine(QWidget *parent, QString text, QString init)
 
   ok->setDefault(true);
 
-  connect(ok, SIGNAL(pressed()), this, SLOT(accept()));
-  connect(cancel, SIGNAL(pressed()), this, SLOT(reject()));
+  connect(ok, SIGNAL(clicked()), this, SLOT(accept()));
+  connect(cancel, SIGNAL(clicked()), this, SLOT(reject()));
 
   adjustSize();
   setFixedSize(this->width(), this->height());
+
+  lineedit->setFocus();
 }
