@@ -4,8 +4,8 @@
 
 #include <qdialog.h>
 #include <qlabel.h>
-#include <qlined.h>
-#include <qpushbt.h>
+#include <qlineedit.h>
+#include <qpushbutton.h>
 
 
 class KInputLine : public QDialog
@@ -27,4 +27,4 @@ private:
 };
 
 
-#endif
\ No newline at end of file
+#endif
