@@ -1,15 +1,17 @@
 #include "toplevel.h"
-#include "toplevel.moc"
 
 #include <qpixmap.h>
 #include <qpainter.h>
+#include <qdatetime.h>
 #include <time.h>
+
 #include <kapp.h>
+#include <kglobal.h>
 #include <klocale.h>
 
 
 TopLevel::TopLevel ()
-  : KTopLevelWidget()
+  : KTMainWindow()
 {
   world = new World(this);
 
@@ -36,26 +38,27 @@ void TopLevel::setupStatusBar()
 {
   statusbar = new KStatusBar(this);
   statusbar->insertItem("", ID_LOCALTIME);
-  statusbar->setInsertOrder(KStatusBar::LeftToRight);
   setStatusBar(statusbar);
 }  
 
 
 void TopLevel::timerEvent(QTimerEvent *)
 {
-  char buffer[160];
-  char buffer1[80];
-
   time_t t = time(NULL) + World::offset;
 
-  struct tm *tmp = localtime(&t);
-  strftime(buffer, 80, klocale->translate  ("Local time: %x, %H:%M:%S"),tmp);
+  QDateTime dattim, dattim1;
+  dattim.setTime_t(t);
+  QString buffer = i18n("Local Time: %1, %2")
+           .arg(KGlobal::locale()->formatDate(dattim.date(), true))
+           .arg(KGlobal::locale()->formatTime(dattim.time(), true));
 
-  tmp = gmtime(&t);
-  strftime(buffer1, 80, klocale->translate ("  GMT Time: %x, %H:%M:%S"),tmp);
+  struct tm *tmp = gmtime(&t);
+  dattim1.setTime_t(mktime(tmp));
+  QString buffer1 = i18n("GMT Time: %1, %2")
+           .arg(KGlobal::locale()->formatDate(dattim1.date(), true))
+           .arg(KGlobal::locale()->formatTime(dattim1.time(), true));
 
-  strcat(buffer, buffer1);
-  statusbar->changeItem(buffer, ID_LOCALTIME);
+  statusbar->changeItem(buffer + " " + buffer1, ID_LOCALTIME);
 
   world->setTime();
 }
