@@ -23,13 +23,13 @@
  * software.
  */
 
-/*	 
+/*	
 **  Xodometer
 **  Written by Mark H. Granoff/mhg
 **             Digital Equipment Corporation
 **             Littleton, MA, USA
 **             17 March 1993
-**  
+**
 **  If you make improvements or enhancements to Xodometer, please send them
 **  back to the author at any of the following addresses:
 **
@@ -38,15 +38,15 @@
 **		72301.1177@CompuServe.com
 **
 **  Thanks to my friend and colleague Bob Harris for his suggestions and help.
-**  
+**
 **  This software is provided as is with no warranty of any kind, expressed or
 **  implied. Neither Digital Equipment Corporation nor Mark Granoff will be
 **  held accountable for your use of this software.
-**  
+**
 **  This software is released into the public domain and may be redistributed
 **  freely provided that all source module headers remain intact in their
 **  entirety, and that all components of this kit are redistributed together.
-**  
+**
 **  Modification History
 **  --------------------
 **  19 Mar 1993	mhg	v1.0	Initial release.
@@ -82,7 +82,7 @@
 **				all Xm references were removed, and VMS
 **				support was dumped!
 **
-** 22 Aug 1998 asn      V3.1    Minor updates to make it compile more 
+** 22 Aug 1998 asn      V3.1    Minor updates to make it compile more
 **                              gracefully on modern C++ compilers,
 **                              and updated things to KDE 1.0 specs.
 **                              Added a proper About Box.
@@ -115,23 +115,26 @@
 
 #include "kodo.h"
 
+const double speedInterval=500.0;
+const double distanceInterval=10.0;
+const int speedSamples=10;
+
 static	struct conversionEntry ConversionTable[MAX_UNIT] = {
-{ inch, "inch", "inches", 12.0,   2.54,     "cm",     "cm",     100.0,  3 },
-{ foot, "foot", "feet",   5280.0, 0.3048,    "meter", "meters", 1000.0, 4 },
-{ mile, "mile", "miles",  -1.0,   1.609344, "km",     "km",     -1.0,   5 }
+    { inch, I18N_NOOP("inch"), I18N_NOOP("inches"), 12.0,   2.54,
+      I18N_NOOP("cm"),     I18N_NOOP("cm"),     100.0,  3 },
+    { foot, I18N_NOOP("foot"),  I18N_NOOP("feet"),   5280.0, 0.3048,
+      I18N_NOOP("meter"),  I18N_NOOP("meters"), 1000.0, 4 },
+    { mile, I18N_NOOP("mile"),  I18N_NOOP("miles"),  -1.0,   1.609344,
+      I18N_NOOP( "km"),     I18N_NOOP("km" ),     -1.0,   5 }
 };
 
-// My port of java's gridbaglayout.  Overkill here, but I need test-cases.
-#include "gridbag.h"
-
-
 /*
  * Set the program up, do lots of ugly initialization.
  * Note that we use installEventFilter on the two KImgNum's
  * to make clicks on them bring up the context-menu.
  */
 Kodometer::Kodometer(QWidget* parent,const char* name)
-    : AnPanel(parent,name)
+    : QFrame(parent,name)
 {
     debug        = 0;
 
@@ -140,17 +143,17 @@ Kodometer::Kodometer(QWidget* parent,const char* name)
 
     root = RootWindow(display,DefaultScreen(display));
 
-    UseMetric = TRUE;
-    Enabled = TRUE;  
-    AutoReset = TRUE;
-    
+    UseMetric = true;
+    Enabled = true;
+    AutoReset = true;
+
     lastXCoord   = lastYCoord = XCoord = YCoord = 0;
     Distance     = 0.0;
     TripDistance = 0.0;
     lastDistance = 0.0;
     speed        = 0.0;
-    
-    
+
+
     pollInterval      = 10;
     saveFrequency     = 10;
     pointerScreen     = -1;
@@ -166,48 +169,45 @@ Kodometer::Kodometer(QWidget* parent,const char* name)
 
     readSettings();
 
-    totalLabel=new KImageNumber(locate("appdata", "57-2.gif"),
-				this,"Total");    
-    tripLabel=new KImageNumber(locate("appdata", "57-2.gif"),this,"Trip");
-//    speedLabel=new KImageNumber(libDir+"57-2.gif",this,"Speed");
-
+    totalLabel = new KImageNumber(locate("appdata", "57-2.png"),
+				  this, "Total");
+    tripLabel  = new KImageNumber(locate("appdata", "57-2.png"),
+				  this, "Trip");
 
     totalLabel->installEventFilter(this);
     tripLabel->installEventFilter(this);
-//    speedLabel->installEventFilter(this);
 
-    QToolTip::add(totalLabel, ConversionTable[distanceUnit].fromUnitTagPlural);
-    QToolTip::add( tripLabel,  ConversionTable[tripDistanceUnit].fromUnitTagPlural);
-    
-    
+    QToolTip::add(totalLabel, i18n(ConversionTable[distanceUnit].fromUnitTagPlural));
+    QToolTip::add(tripLabel,  i18n(ConversionTable[tripDistanceUnit].fromUnitTagPlural));
+
     // Make the popup menu
 
     menu = new QPopupMenu();
 
-    menu->insertItem("Mouspedometa");
+    menu->insertItem(i18n("Mouspedometa"));
     menu->insertSeparator();
-    
-    enabledID=menu->insertItem
-	("&Enable",this,SLOT(toggleEnabled()),CTRL+Key_E);
-    
-    metricID=menu->insertItem
-	("&Metric Display",this,SLOT(toggleUnits()),CTRL+Key_M);
-    
-    autoResetID=menu->insertItem
-	("Auto &Reset Trip",this,SLOT(toggleAutoReset()),CTRL+Key_R);
-    
-    menu->insertItem("Reset &Trip",this,SLOT(resetTrip()),CTRL+Key_T);
-    menu->insertItem("Reset &Odometer",this,SLOT(resetTotal()),CTRL+Key_O);
-    menu->insertSeparator();
-    
-    menu->insertItem("&About Mouspedometa...",this,SLOT(about()),CTRL+Key_A);
-    menu->insertItem("&Help",this,SLOT(help()),CTRL+Key_H);
-    menu->insertSeparator();
-    
-    menu->insertItem("&Quit",this,SLOT(quit()),CTRL+Key_Q);
-    menu->setCheckable( TRUE );
 
-    
+    enabledID=menu->insertItem
+	(i18n("&Enable"),this,SLOT(toggleEnabled()),CTRL+Key_E);
+
+    metricID=menu->insertItem
+	(i18n("&Metric Display"),this,SLOT(toggleUnits()),CTRL+Key_M);
+
+    autoResetID=menu->insertItem
+	(i18n("Auto &Reset Trip"),this,SLOT(toggleAutoReset()),CTRL+Key_R);
+
+    menu->insertItem(i18n("Reset &Trip"),this,SLOT(resetTrip()),CTRL+Key_T);
+    menu->insertItem(i18n("Reset &Odometer"),this,SLOT(resetTotal()),CTRL+Key_O);
+    menu->insertSeparator();
+
+    menu->insertItem(i18n("&About Mouspedometa..."),this,SLOT(about()),CTRL+Key_A);
+    menu->insertItem(i18n("&Help"),this,SLOT(help()),CTRL+Key_H);
+    menu->insertSeparator();
+
+    menu->insertItem(i18n("&Quit"),this,SLOT(quit()),CTRL+Key_Q);
+    menu->setCheckable( true );
+
+
     menu->setItemChecked(metricID,UseMetric);
     menu->setItemChecked(autoResetID,AutoReset);
     menu->setItemChecked(enabledID,Enabled);
@@ -215,42 +215,9 @@ Kodometer::Kodometer(QWidget* parent,const char* name)
     distanceID=startTimer((int)distanceInterval);
     speedID=startTimer((int)speedInterval);
 
+    tripLabel->move(0, totalLabel->height());
+    setFixedSize(tripLabel->width(), totalLabel->height() + tripLabel->height());
 
-    // Evil GridBagLayout code, the way REAL men do layout.
-
-    GridBagConstraints gc;
-
-    gb->setInsets(Insets(0,0,0,0));
-
-    gc.gridx=0;
-    gc.gridy=0;
-    gc.anchor=GridBagConstraints::CENTER;
-    gc.fill=GridBagConstraints::HORIZONTAL;
-    gc.weightx=1;
-    gc.weighty=0;
-    gc.gridwidth=1;    
-    setConstraints(totalLabel,gc);
-
-    gc.gridx=0;
-    gc.gridy=1;
-    gc.anchor=GridBagConstraints::NORTH;
-    gc.fill=GridBagConstraints::HORIZONTAL;
-    gc.weightx=1;
-    gc.weighty=1;
-    gc.gridwidth=1; 
-    setConstraints(tripLabel,gc);
-
-
-    
-/*    gc.gridx=0;
-    gc.gridy=2;
-    gc.anchor=GridBagConstraints::NORTH;
-    gc.fill=GridBagConstraints::HORIZONTAL;
-    gc.weightx=1;
-    gc.weighty=1;
-    gc.gridwidth=1; 
-    setConstraints(speedLabel,gc);
-*/
     refresh();
 }
 
@@ -269,7 +236,7 @@ void Kodometer::FindAllScreens(void)
     int i = 0;
     int Dh, DhMM, Dw, DwMM;
     double vPixelsPerMM, hPixelsPerMM;
-    
+
     screenCount = ScreenCount(display);
 //    if (debug) printf("Display has %d screen%s\n", screenCount, (screenCount == 1 ? "" : "s"));
 
@@ -278,7 +245,7 @@ void Kodometer::FindAllScreens(void)
 //	if (debug) printf("Screen %d\n", i);
 	screenInfo[i].root = RootWindow(display, i);
 	screenInfo[i].scr = XScreenOfDisplay(display, i);
-    
+
 	screenInfo[i].height = Dh = HeightOfScreen(screenInfo[i].scr);
 	DhMM = HeightMMOfScreen(screenInfo[i].scr);
 	screenInfo[i].width = Dw = WidthOfScreen(screenInfo[i].scr);
@@ -312,9 +279,9 @@ bool Kodometer::eventFilter( QObject *, QEvent *e )
 {
     if ( e->type() == QEvent::MouseButtonPress ) {
 	mousePressEvent((QMouseEvent*)e);
-	return TRUE;                        
+	return true;
     }
-    return FALSE; 
+    return false;
 }
 
 /*
@@ -342,14 +309,13 @@ void Kodometer::timerEvent(QTimerEvent* e)
 
 	    XQueryPointer (display, root, &RootIDRet, &ChildIDRet, &XCoord,
 			   &YCoord, &WinX, &WinY, &StateMask);
-	    
+	
 	    if (CalcDistance())
 	    {
-		
 		refresh();
 		cyclesSinceLastSave++;
 	    }
-	    
+	
 	}
 /*	else {
 
@@ -359,18 +325,18 @@ void Kodometer::timerEvent(QTimerEvent* e)
 
 	    QListIterator<double> it(speeds);
 	    double total=0;
-	    
+	
 	    for ( ; it.current(); ++it)  {
 		double* d = it.current();
 		total+= (*d);
 	    }
 
 	    total/=speeds.count();
-	    
+	
 	    speed = 36000*total/speedInterval;
-	    
+	
 	    lastDistance=Distance;
-	    
+	
 	    refresh();
 	    }*/
     }
@@ -383,7 +349,7 @@ void Kodometer::toggleEnabled()
     Enabled = !Enabled;
 
     menu->setItemChecked(enabledID,Enabled);
-    
+
     refresh();
 }
 
@@ -393,7 +359,7 @@ void Kodometer::toggleAutoReset()
     AutoReset = !AutoReset;
 
     menu->setItemChecked(autoResetID,AutoReset);
-    
+
     refresh();
 }
 
@@ -405,27 +371,26 @@ void Kodometer::toggleUnits()
 
     menu->setItemChecked(metricID,UseMetric);
 
-    
     QToolTip::remove(totalLabel);
-    
+
     if(UseMetric==0)
 	QToolTip::add(totalLabel,
-		      ConversionTable[distanceUnit].fromUnitTagPlural);
+		      i18n(ConversionTable[distanceUnit].fromUnitTagPlural));
     else
 	QToolTip::add(totalLabel,
-		      ConversionTable[distanceUnit].toUnitTagPlural);
+		      i18n(ConversionTable[distanceUnit].toUnitTagPlural));
+
 
 
-    
     QToolTip::remove(tripLabel);
-    
+
     if(UseMetric==0)
 	QToolTip::add(tripLabel,
-		      ConversionTable[tripDistanceUnit].fromUnitTagPlural);
+		      i18n(ConversionTable[tripDistanceUnit].fromUnitTagPlural));
     else
 	QToolTip::add(tripLabel,
-		      ConversionTable[tripDistanceUnit].toUnitTagPlural);
-    
+		      i18n(ConversionTable[tripDistanceUnit].toUnitTagPlural));
+
     refresh();
 }
 
@@ -442,13 +407,13 @@ void Kodometer::resetTrip()
 void Kodometer::resetTotal()
 {
     resetTrip();
-    
+
     Distance=0.0;
     distanceUnit=inch;
-    
+
     TripDistance = 0.0;
     tripDistanceUnit = inch;
-    
+
     refresh();
 }
 
@@ -465,7 +430,7 @@ void Kodometer::quit()
  */
 void Kodometer::refresh(void)
 {
-    
+
     if(distanceUnit!=lastDUnit) {
 
 	distanceUnit=lastDUnit;
@@ -474,10 +439,10 @@ void Kodometer::refresh(void)
 
 	if(UseMetric==0)
 	    QToolTip::add(totalLabel,
-			  ConversionTable[distanceUnit].fromUnitTagPlural);
+			  i18n(ConversionTable[distanceUnit].fromUnitTagPlural));
 	else
 	    QToolTip::add(totalLabel,
-			  ConversionTable[distanceUnit].toUnitTagPlural);
+			  i18n(ConversionTable[distanceUnit].toUnitTagPlural));
     }
 
     if(tripDistanceUnit!=lastTUnit) {
@@ -488,38 +453,33 @@ void Kodometer::refresh(void)
 
 	if(UseMetric==0)
 	    QToolTip::add(tripLabel,
-			  ConversionTable[tripDistanceUnit].fromUnitTagPlural);
+			  i18n(ConversionTable[tripDistanceUnit].fromUnitTagPlural));
 	else
 	    QToolTip::add(tripLabel,
-			  ConversionTable[tripDistanceUnit].toUnitTagPlural);
+			  i18n(ConversionTable[tripDistanceUnit].toUnitTagPlural));
     }
-    
-    
+
+
     QString distance_s;
     QString trip_s;
 
     if (Enabled) {
 	
-	FormatDistance(Distance, distanceUnit, distance_s);
-	FormatDistance(TripDistance, tripDistanceUnit, trip_s);
+	distance_s = FormatDistance(Distance, distanceUnit);
+	trip_s = FormatDistance(TripDistance, tripDistanceUnit);
     }
     else {
 	
-	distance_s="------";
-	trip_s="------";
+	distance_s ="------";
+	trip_s ="------";
     }
 
-//    if (strcmp(distance_s, prev_distance_s) != 0)
-
     double d=atof(distance_s);
     totalLabel->setValue(d);
 
-//    if (strcmp(trip_s, prev_trip_s) != 0)
-
     d=atof(trip_s);
     tripLabel->setValue(d);
 
-//    speedLabel->setValue(speed);
 }
 
 /*
@@ -545,7 +505,6 @@ double Kodometer::multiplier(Units unit)
  * This is code from the original program, responsible for converting the
  * number of pixels traveled into  a real-world coordinates.
  */
-#define MAX(_a,_b) ((_a) > (_b) ? (_a) : (_b))
 int Kodometer::CalcDistance(void)
 {
     double dist, sum;
@@ -560,12 +519,12 @@ int Kodometer::CalcDistance(void)
     int screenOrientation=K_Left;
 
     i = j = finalScreen = increment = 0;
-    
+
     if (lastXCoord == 0 && lastYCoord == 0)
-	return FALSE;
+	return false;
 
     if (lastXCoord == XCoord && lastYCoord == YCoord)
-	return FALSE;
+	return false;
 	
     /* Figure out which screen the pointer is on */
     if (screenCount > 1)
@@ -576,10 +535,10 @@ int Kodometer::CalcDistance(void)
 		i++;
 
     pointerScreen = i;
-    
+
 //    if (debug) printf("CalcDistance: screen: %d, x: %d, y: %d\n", pointerScreen, XCoord, YCoord);
 
-    /*	 
+    /*	
     **  Adjust XCoord or YCoord for the screen its on, relative to screen 0
     **	and screenOrientation.
     */
@@ -591,12 +550,12 @@ int Kodometer::CalcDistance(void)
 	    case K_Left:
 	    case K_Top:
 		finalScreen = 0;
-		j = MAX(pointerScreen,lastPointerScreen) - 1;
+		j = QMAX(pointerScreen,lastPointerScreen) - 1;
 		increment = -1;
 		break;
 	    case K_Right:
 	    case K_Bottom:
-		finalScreen = MAX(pointerScreen,lastPointerScreen) - 1;
+		finalScreen = QMAX(pointerScreen,lastPointerScreen) - 1;
 		j = 0;
 		increment = 1;
 		break;
@@ -633,10 +592,10 @@ int Kodometer::CalcDistance(void)
 
     X = XCoord - lastXCoord;
     X = X*X;
-    
+
     Y = YCoord - lastYCoord;
     Y = Y*Y;
-    
+
     sum = (double)X + (double)Y;
     dist = sqrt(sum);
 
@@ -665,23 +624,23 @@ int Kodometer::CalcDistance(void)
 	
 	currentUnit++;
     }
-    
+
 //    if (debug) printf("\n Next part \n");
 
-    
+
     oldDistance = Distance * multiplier(distanceUnit);
-    
+
     Distance += finalNewDist;
     oldDistanceUnit = distanceUnit;
 
-    
+
     if (ConversionTable[distanceUnit].maxFromBeforeNext != -1.0 &&
 	Distance >= ConversionTable[distanceUnit].maxFromBeforeNext)
     {
 	Distance = Distance / ConversionTable[distanceUnit].maxFromBeforeNext;
 	distanceUnit++;
     }
-    
+
     newDistance = Distance * multiplier(distanceUnit);
     distanceChanged = (distanceUnit != oldDistanceUnit ||
 		       (unsigned int)oldDistance != (unsigned int)newDistance);
@@ -689,7 +648,7 @@ int Kodometer::CalcDistance(void)
     /* Add an appropriate value to TripDistance, which may be in a unit other than inches */
     currentUnit = inch;
     finalNewDist = distInches;
-    
+
     while (currentUnit < tripDistanceUnit)
     {
 	finalNewDist = finalNewDist / ConversionTable[currentUnit].maxFromBeforeNext;
@@ -699,7 +658,7 @@ int Kodometer::CalcDistance(void)
     oldTripDistance = TripDistance * multiplier(tripDistanceUnit);
     TripDistance += finalNewDist;
     oldTripDistanceUnit = tripDistanceUnit;
-    
+
     if (ConversionTable[tripDistanceUnit].maxFromBeforeNext != -1.0 &&
 	TripDistance >= ConversionTable[tripDistanceUnit].maxFromBeforeNext)
     {
@@ -707,18 +666,18 @@ int Kodometer::CalcDistance(void)
 	tripDistanceUnit++;
     }
 
-    
+
     newTripDistance = TripDistance * multiplier(tripDistanceUnit);
     tripDistanceChanged = (tripDistanceUnit != oldTripDistanceUnit ||
 		       (unsigned int)oldTripDistance != (unsigned int)newTripDistance);
 
-    
+
 //    if (debug) printf("Out: Distance: %.5f, Trip Distance: %.5f\n", Distance, TripDistance);
 
     if (distanceChanged || tripDistanceChanged)
-	return TRUE;
+	return true;
     else
-	return FALSE;
+	return false;
 }
 
 
@@ -728,8 +687,9 @@ int Kodometer::CalcDistance(void)
  * pretty OO world.
  */
 #define THERE_IS_A_NEXT (ConversionTable[unit].maxToBeforeNext != -1.0)
-void Kodometer::FormatDistance(double in_dist, Units unit,QString& string)
+QString Kodometer::FormatDistance(double in_dist, Units unit)
 {
+    QString string;
     double out_dist = in_dist;
     const char *tag;
     int precision;
@@ -757,6 +717,7 @@ void Kodometer::FormatDistance(double in_dist, Units unit,QString& string)
     precision = ConversionTable[unit].printPrecision;
 
     string.sprintf ("%.*f %s", precision, out_dist, tag);
+    return string;
 }
 
 
@@ -783,13 +744,13 @@ void Kodometer::readSettings(void)
 
     // If the user has AutoReset on, set the trip value to 0.
     // This is REALLY not a good plce to be doing this.
-    if(AutoReset) {
+    if(false) {
 	TripDistance=0.0;
 	tripDistanceUnit=inch;
     }
 
     lastDistance=Distance;
-    
+
     lastDUnit=distanceUnit;
     lastTUnit=tripDistanceUnit;
 }
@@ -802,8 +763,6 @@ void Kodometer::saveSettings(void)
 {
     KConfig *config = KApplication::kApplication()->config();
     config->setGroup( "Settings" );
-    
-    QString str;
 
     config->writeEntry( "UseMetric", UseMetric );
 
@@ -814,7 +773,7 @@ void Kodometer::saveSettings(void)
 
     config->writeEntry( "TripUnit", tripDistanceUnit);
     config->writeEntry( "DistanceUnit", distanceUnit);
-    
+
     config->sync();
 }
 
@@ -822,135 +781,44 @@ void Kodometer::saveSettings(void)
 // Callback to display help
 void Kodometer::help()
 {
-    KApplication::kApplication()->invokeHTMLHelp( "" , "" );
+    KApplication::kApplication()->invokeHelp();
 }
 
 
 void Kodometer::about()
 {
-/*    if(aboutDialog==NULL) {
-
-	aboutDialog=new AnPanel(0,"about");
-
-	QLabel* author=new QLabel(aboutDialog,"author");
-	author->setText("By Armen Nakashian <armen@nakashian.com>");
-
-	QLabel* version=new QLabel(aboutDialog,"version");
-	version->setText("Mouspedometa V0.2");
-
-	QLabel* homepage=new QLabel(aboutDialog,"homepage");
-	homepage->setText("http://yawara.anime.net/kodo/");
-
-	QPushButton* done=new QPushButton(aboutDialog,"done");
-	done->setText("OK");
-	
-	GridBagConstraints gc;
-	
-	gb->setInsets(Insets(3,3,3,3));
-	
-	gc.gridx=0;
-	gc.gridy=0;
-	gc.anchor=GridBagConstraints::CENTER;
-	gc.fill=GridBagConstraints::NONE;
-	gc.weightx=1;
-	gc.weighty=0;
-	gc.gridwidth=1;    
-	aboutDialog->setConstraints(version,gc);
-	
-	gc.gridx=0;
-	gc.gridy=1;
-	gc.anchor=GridBagConstraints::NORTH;
-	gc.fill=GridBagConstraints::NONE;
-	gc.weightx=1;
-	gc.weighty=0;
-	gc.gridwidth=1; 
-	aboutDialog->setConstraints(author,gc);
-	
-
-	gc.gridx=0;
-	gc.gridy=2;
-	gc.anchor=GridBagConstraints::NORTH;
-	gc.fill=GridBagConstraints::NONE;
-	gc.weightx=1;
-	gc.weighty=0;
-	gc.gridwidth=1; 
-	aboutDialog->setConstraints(homepage,gc);
-	
-	
-	gc.gridx=0;
-	gc.gridy=3;
-	gc.anchor=GridBagConstraints::SOUTH;
-	gc.fill=GridBagConstraints::NONE;
-	gc.weightx=1;
-	gc.weighty=1;
-	gc.gridwidth=1; 
-	aboutDialog->setConstraints(done,gc);
-
-	cout << done->sizeHint().width() << ", "
-	     << done->sizeHint().height()
-	     << endl;
-
-
-	connect(done,SIGNAL(clicked()),
-		this,SLOT(aboutdone()));	
-    }
-
-
-    aboutDialog->resize(aboutDialog->pack());
-    aboutDialog->setMaximumSize(aboutDialog->pack());
-    
-    aboutDialog->show();
-*/
-
-    
     QMessageBox::about( this, i18n("About Mouspedometa"),
 			i18n("Mouspedometa measures your desktop mileage.\n"
-			"Copyright 1998 Armen Nakashian\n\n"
-			"This program is free, do with it what you will.\n"
-			"This program is part of the K Desktop Environment.\n\n"
-			"http://yawara.anime.net/kodo/\n\n"));
+			     "Copyright 1998 Armen Nakashian\n\n"
+			     "This program is free, do with it what you will.\n"
+			     "This program is part of the K Desktop Environment.\n\n"
+			     "http://yawara.anime.net/kodo/\n\n"));
 }
 
 static const char* description=I18N_NOOP("Mouspedometa measures your desktop mileage");
 
 int main(int argc,char **argv)
 {
-    
+
     /* Top level details */
 
     KAboutData aboutData("kodo", I18N_NOOP("Mouspedometa"),
-        VERSION, description, KAboutData::License_GPL,
-        "(c) 1998, Armen Nakashian");
+			 VERSION, description, KAboutData::License_GPL,
+			 "(c) 1998, Armen Nakashian");
     aboutData.addAuthor("Armen Nakashian",0, 0,"http://yawara.anime.net/kodo/");
     KCmdLineArgs::init( argc, argv, &aboutData );
-    
+
     KApplication a;
-    // We need a top-level widget for the GridBag panel.
-    KTMainWindow w;
-    
-    Kodometer o(&w,"Kodo");
+
+    Kodometer o(0,"Kodo");
 
     // Get rid of the title bar.
-    KWM::setDecoration(w.winId(),KWM::tinyDecoration);
-    a.setMainWidget(&w);
+    KWM::setDecoration(o.winId(),KWM::tinyDecoration);
+    a.setMainWidget(&o);
+    a.setTopWidget(&o);
 
-    // session management!
-#warning fix session management
-#if 0    
-    a.enableSessionManagement(true);
-    a.setWmCommand(argv[0]);
-#endif    
-    a.setTopWidget(&w);
+    o.show();
 
-    
-    w.setView(&o);
-
-    // Resize the window to the size needed, and then fix it there.
-    w.resize(o.pack());
-    w.setMaximumSize(o.pack());
-
-    w.show();
-    
     return a.exec();
 }
 
